@@ -1,3 +1,3 @@
 import fkeycapture as _f
 def get(keycount=1,bytes=False):
-  _f.get(keycount=1,bytes=False)
\ No newline at end of file
+  _f.getkey(keycount=1,bytes=False)
\ No newline at end of file
