@@ -29,7 +29,7 @@ def getp1():
 def getp2():
     termios.tcsetattr(fd, termios.TCSAFLUSH, attrs_save)
     fcntl.fcntl(fd, fcntl.F_SETFL, flags_save)
-def get(keycount=1,bytes=False):
+def getkey(keycount=1,bytes=False):
   getp1()
   key = sys.stdin.read(keycount)
   getp2()
